4.27. umbra.globals.runtimeGlobals — Umbra 1.0.9 documentation

# 4.27. umbra.globals.runtimeGlobals

RuntimeGlobals.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines Umbra package runtime globals through the `RuntimeGlobals` class.

Others:

## 4.27.1. Classes

class `umbra.globals.runtimeGlobals.` `RuntimeGlobals`

  Defines Umbra package runtime constants.

  `parameters` = None

    Application startup parameters.

  `arguments` = None

    Application startup arguments.

  `loggingConsoleHandler` = <logging.StreamHandler object at 0x106b20e10>

    Logging console handler instance.

  `loggingFileHandler` = None

    Logging file handler instance.

  `loggingSessionHandler` = None

    Logging session handler instance.

  `loggingSessionHandlerStream` = None

    Logging session handler stream.

  `loggingFormatters` = {u'Default': <logging.Formatter object at 0x10673f990>, u'Extended': <logging.Formatter object at 0x10673f9d0>, u'Standard': <logging.Formatter object at 0x10673fa10>}

    Logging formatters.

  `loggingActiveFormatter` = None

    Logging current formatter.

  `verbosityLevel` = None

    Logging current verbosity level.

  `loggingFile` = None

    Application logging file.

  `requestsStack` = None

    Application requests stack.

  `engine` = None

    Application engine instance.

  `patchesManager` = None

    Application patches manager instance.

  `componentsManager` = None

    Application components manager instance.

  `actionsManager` = None

    Application actions manager instance.

  `fileSystemEventsManager` = None

    Application file system events manager instance.

  `notificationsManager` = None

    Application notifications manager instance.

  `layoutsManager` = None

    Application layouts manager instance.

  `reporter` = None

    Application reporter instance.

  `application` = None

    Application instance.

  `userApplicationDataDirectory` = None

    Application user data directory.

  `resourcesDirectories` = [u'/Users/kelsolaar/Documents/Development/Umbra/docs/sphinx/source/resources/packages/umbra/resources']

    Resources paths.

  `uiFile` = u'/Users/kelsolaar/Documents/Development/Umbra/docs/sphinx/source/resources/packages/umbra/resources/Umbra.ui'

    Application ui file.

  `patchesFile` = None

    Application patches file.

  `settingsFile` = None

    Application settings file.

  `settings` = None

    Application settings instance.

  `lastBrowsedPath` = '/Applications/Aptana Studio 3/AptanaStudio3.app/Contents/MacOS'

    Last browsed path.

  `splashscreenImage` = None

    Application splashscreen picture.

  `splashscreen` = None

    Application splashscreen instance.